@@ -148,7 +148,8 @@ def calc_stats_merged(m_all_i, m_all_nmeas, d_max=0, d_min=0, n_bins=10):
     # overall values
     i_mean = m_all_i.mean()
     i_sig = m_all_i.i_over_sig_i()
-    n_obs = int(m_all_nmeas.sum())
+    # n_obs = int(m_all_nmeas.sum())
+    n_obs = sum(m_all_nmeas.data().iround())
     multiplicity = m_all_nmeas.mean()
     stats["overall"]["d_max"] = round(res_low, 3)
     stats["overall"]["d_min"] = round(res_high, 3)
@@ -183,7 +184,8 @@ def calc_stats_merged(m_all_i, m_all_nmeas, d_max=0, d_min=0, n_bins=10):
         res_low, res_high = m_all_i_sel.d_max_min()
         n_unique = m_all_i_sel.size()
         completeness = m_all_i_sel.as_non_anomalous_set().completeness(d_max=res_low)
-        n_obs = int(m_all_nmeas_sel.sum())
+        # n_obs = int(m_all_nmeas_sel.sum())
+        n_obs = sum(m_all_nmeas_sel.data().iround())
         n_ref_nmeas = int(m_all_nmeas_sel.size())
         multiplicity = m_all_nmeas_sel.mean()
         i_mean =  m_all_i_sel.mean()
@@ -454,6 +456,40 @@ class MyArgumentParser(argparse.ArgumentParser):
         sys.exit(2)
 
 
+def get_cell_cellfile(cellfile):
+    with open(cellfile, 'r') as f:
+        lines = f.readlines()
+    cell = [None, None, None, None, None, None]
+    for line in lines:
+        try:
+            if line.split()[0] == "al" and line.split()[-1] == "deg":
+                cell[3] = float(line.split()[-2])
+            elif line.split()[0] == "be" and line.split()[-1] == "deg":
+                cell[4] = float(line.split()[-2])
+            elif line.split()[0] == "ga" and line.split()[-1] == "deg":
+                cell[5] = float(line.split()[-2])
+            elif line.split()[0] == "a" and line.split()[-1] == "A":
+                cell[0] = float(line.split()[-2])
+            elif line.split()[0] == "b" and line.split()[-1] == "A":
+                cell[1] = float(line.split()[-2])
+            elif line.split()[0] == "c" and line.split()[-1] == "A" and not "centering" in line:
+                cell[2] = float(line.split()[-2])
+        except:
+            continue
+    print("")
+    if (cell[0] and cell[1] and cell[2] and cell[3] and cell[4] and cell[5]):
+        print(f"Unit cell parameters found in file {cellfile}:")
+        print(" ".join(map(str, cell)))
+    else:
+        sys.stderr.write(
+            f"WARNING: Unit cell parameters could not be parsed from "
+            f"the file {cellfile}.\n"
+            f"         Attempt to find the unit cell parameters found "
+            f"in this file: " + " ".join(map(str, cell)) + "\n")
+        cell = None
+    return cell
+
+
 def run():
     from . import __version__
     if not which("f2mtz"):
@@ -486,6 +522,12 @@ def run():
         metavar=("cell_a", "cell_b", "cell_c", "cell_alpha", "cell_beta", "cell_gamma"),
         # required=True
     )
+    parser.add_argument_with_check(
+        "--cellfile",
+        metavar=("cell_file"),
+        help="Cell file from CrystFEL",
+        type=str,
+    )
     parser.add_argument_with_check(
         "--half-dataset",
         metavar=("hkl1", "hkl2"),
@@ -550,12 +592,11 @@ def run():
     elif reflection_file_reader.any_reflection_file(hklin).file_type() == None:
         hklin_format = "crystfel"
         spacegroup = None
-        cell_str = None
+        cell = None
+        # cell_str = None
 
     if args.spacegroup:
         spacegroup = args.spacegroup  # TO DO
-    if args.cell:
-        cell = args.cell  # TO DO
 
     if not args.project:
         project = "project"
@@ -579,23 +620,26 @@ def run():
     d_max = args.d_max
     d_min = args.d_min
     n_bins = args.n_bins
-    if args.cell:
-        cell_str = str(args.cell[0]) + " " + str(args.cell[1]) + " " + str(args.cell[2]) + " " + str(args.cell[3]) + " " + str(args.cell[4]) + " " + str(args.cell[5])
-    # crystfel: check whether we know spacegroup and cell
-    # dials: direct input arguments in command line for spacegroup and cell have higher priority
-
-    if hklin_format == "crystfel" and not spacegroup:
-        sys.stderr.write(
-            "ERROR: Space group was not specified but is required for CrystFEL.\n"
-            "       Specify space group explictely or provide reference PDB or mmCIF file.\n"
-            "       Aborting.\n")
-        sys.exit(1)
-    if hklin_format == "crystfel" and not cell_str:
-        sys.stderr.write(
-            "ERROR: Unit cell parameters were not specified but are required for CrystFEL.\n"
-            "       Specify unit cell parameters explictely or provide reference PDB or mmCIF file or .cell file.\n"
-            "       Aborting.\n")
-        sys.exit(1)
+    if hklin_format == "crystfel":
+        if args.cellfile:
+            cell = get_cell_cellfile(args.cellfile)
+        if args.cell:
+            cell = args.cell
+            # cell_str = str(args.cell[0]) + " " + str(args.cell[1]) + " " + str(args.cell[2]) + " " + str(args.cell[3]) + " " + str(args.cell[4]) + " " + str(args.cell[5])
+        # crystfel: check whether we know spacegroup and cell
+        # dials: direct input arguments in command line for spacegroup and cell have higher priority
+        if not spacegroup:
+            sys.stderr.write(
+                "ERROR: Space group was not specified but is required for CrystFEL.\n"
+                "       Specify space group explictely or provide reference PDB or mmCIF file.\n"
+                "       Aborting.\n")
+            sys.exit(1)
+        if not cell:
+            sys.stderr.write(
+                "ERROR: Unit cell parameters were not specified but are required for CrystFEL.\n"
+                "       Specify unit cell parameters explictely or provide reference PDB or mmCIF file or .cell file.\n"
+                "       Aborting.\n")
+            sys.exit(1)
     print("")
     print("")
     print("DATA STATISTICS:")
